<!-- insertion marker -->

## [v0.5.2](https://github.com/MarTrepodi/mhanndalorian-bot-api/releases/tag/v0.5.2) - 2025-04-13

<small>[Compare with v0.5.1](https://github.com/MarTrepodi/mhanndalorian-bot-api/compare/v0.5.1...v0.5.2)</small>

### Features

- add example scripts and README files for
  usage ([63350b7](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/63350b75bf409206bd84a7096dbf9c73aacbf790)
  by MarTrepodi).
- add optional 'enums' parameter to API
  methods ([6c78a07](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/6c78a072bdb1c76e8d37ade5bec88b588f772b62)
  by MarTrepodi).
- add human-readable unix time conversion
  utility ([afb2001](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/afb2001f5ce8672cc3fc3d5c7b0812f50201a859)
  by MarTrepodi).

## [v0.5.1](https://github.com/MarTrepodi/mhanndalorian-bot-api/releases/tag/v0.5.1) - 2025-04-13

<small>[Compare with first commit](https://github.com/MarTrepodi/mhanndalorian-bot-api/compare/d8ca0c85027fde044efebcfd42923012183ec2d1...v0.5.1)</small>

### Features

- add support for fetching Territory War (TW)
  data ([d829bab](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/d829bab68808069dcc02e430531ea9bd4b0fa792)
  by MarTrepodi).
- enhance player and guild data
  handling ([9f99a24](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/9f99a24470748f54d96e9b6ae64c37446a3ed0bf)
  by MarTrepodi).
- add support for player and guild data
  fetching ([86968ea](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/86968ea93716da5be848042e3af4d5adc336aca8)
  by MarTrepodi).
- configure semantic-release for automated
  versioning ([16ee448](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/16ee448dfbf0380e400b2b0c88e2271ffef13f87)
  by MarTrepodi).
- add new endpoints for TB and raid data
  fetching ([caf9485](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/caf94852f32b1a918e43d66c6ad9180cff2da32b)
  by MarTrepodi).
- add x-discord-id header for Registry
  endpoints ([febde24](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/febde24cc746e5ba8373610182aa54aa0d8aa175)
  by MarTrepodi).

### Code Refactoring

- add input validation and simplify
  logic ([80bef6a](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/80bef6ab2bdf87ab2351891550bc748f136666c8)
  by MarTrepodi).
